        function getF(rr,cc){
       if(rr==6 && cc==0){return '../../SIN/030/cl0_tz_500.png';}
       if(rr==29 && cc==0){return 'prob_10fg6_thr11_cl0.png';}
       if(rr==30 && cc==0){return 'prob_10fg6_thr22_cl0.png';}
       if(rr==31 && cc==0){return 'prob_10fg6_thr34_cl0.png';}
       if(rr==32 && cc==0){return 'prob_10fg6_thr48_cl0.png';}
       if(rr==33 && cc==0){return 'prob_10fg6_thr64_cl0.png';}
}
